@@ -17,7 +17,7 @@
 
 classdef duration
   ## -*- texinfo -*-
-  ## @deftp {Class} duration
+  ## @deftp {datatypes} duration
   ##
   ## Array representing durations of time using fixed-length time units.
   ##
@@ -591,9 +591,8 @@ classdef duration
 ################################################################################
 ##                             Available Methods                              ##
 ##                                                                            ##
-## 'size'             'ndims'            'numel'            'histcounts'      ##
-## 'min'              'max'              'mink'             'maxk'            ##
-## 'nnz'              'plot'                                                  ##
+## 'size'             'ndims'            'numel'            'nnz'             ##
+## 'length'           'keyHash'                                               ##
 ##                                                                            ##
 ################################################################################
 
@@ -665,6 +664,77 @@ classdef duration
       out = 1;
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{out} =} nnz (@var{D})
+    ##
+    ## Number of nonzero elements in duration array.
+    ##
+    ## @code{@var{out} = nnz (@var{D})} returns the number of nonzero
+    ## elements in the duration array @var{D}.
+    ##
+    ## @end deftypefn
+    function out = nnz (this)
+      m = this.Months(:);
+      d = this.Days(:);
+      h = hours (this.Time(:));
+      out = numel (m) - sum (m == 0 & d == 0 & h == 0);
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{N} =} length (@var{D})
+    ##
+    ## Length of a duration vector.
+    ##
+    ## @code{@var{N} = length (@var{D})} returns the size of the longest
+    ## dimension of the duration array @var{D}, unless any of its dimensions has
+    ## zero length, in which case @code{length (@var{D})} returns 0.
+    ##
+    ## @end deftypefn
+    function N = length (this)
+      if (isempty (this.Days))
+        N = 0;
+      else
+        N = max (size (this.Days));
+      endif
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{hey} =} keyHash (@var{D})
+    ##
+    ## Generate a hash code for duration array.
+    ##
+    ## @code{@var{h} = keyHash (@var{D})} generates a @qcode{uint64} scalar that
+    ## represents the input array @var{D}.  @code{keyHash} utilizes the 64-bit
+    ## FMV-1a variant of the Fowler-Noll-Vo non-cryptographic hash function.
+    ##
+    ## @code{@var{h} = keyHash (@var{D}), @var{base}} also generates a 64-bit
+    ## hash code using @var{base} as the offset basis for the FNV-1a hash
+    ## algorithm.  @var{base} must be a @qcode{uint64} integer type scalar.  Use
+    ## this syntax to cascade @code{keyHash} on multiple objects for which a
+    ## single hash code is required.
+    ##
+    ## Note that unlike MATLAB, this implementation does no use any random seed.
+    ## As a result, @code{keyHash} will always generate the exact same hash key
+    ## for any particular input across different workers and Octave sessions.
+    ##
+    ## @end deftypefn
+    function key = keyHash (this, base = [])
+      ## Initialize string with size and class name
+      size_str = sprintf ('%dx', size (this.Days))(1:end-1);
+      init_str = [size_str 'duration'];
+      if (base)
+        if (! (isscalar (base) && isa (base, 'uint64')))
+          error ("duration.keyHash: BASE must be a UINT64 scalar.");
+        endif
+        key = __ckeyHash__(init_str, base);
+      else
+        key = __ckeyHash__(init_str);
+      endif
+      if (! isempty (this.Days))
+        key = __nkeyHash__(this.Days(:), key);
+      endif
+    endfunction
+
   endmethods
 
 ################################################################################
@@ -700,10 +770,32 @@ classdef duration
       endif
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} iscolumn (@var{D})
+    ##
+    ## Return true if duration array is a column vector.
+    ##
+    ## @code{@var{TF} = iscolumn (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is a column vector
+    ## and @qcode{false} otherwise.  A column vector is a 2-D array for which
+    ## @code{size (@var{X})} returns @code{[@var{N}, 1]} with non-negative
+    ## @var{N}.
+    ##
+    ## @end deftypefn
     function TF = iscolumn (this)
       TF = iscolumn (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} isempty (@var{D})
+    ##
+    ## Return true if duration array is empty.
+    ##
+    ## @code{@var{TF} = isempty (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is empty and
+    ## @qcode{false} otherwise.
+    ##
+    ## @end deftypefn
     function TF = isempty (this)
       TF = isempty (this.Days);
     endfunction
@@ -719,7 +811,7 @@ classdef duration
       args = varargin;
       [args{:}] = promote (varargin{:});
       days = cellfun (@(obj) obj.Days, args, 'UniformOutput', false);
-      TF = isequal (days{:});
+      TF = isequaln (days{:});
     endfunction
 
     function TF = isfinite (this)
@@ -730,10 +822,48 @@ classdef duration
       TF = isinf (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} ismatrix (@var{D})
+    ##
+    ## Return true if duration array is a 2-D array.
+    ##
+    ## @code{@var{TF} = ismatrix (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is a matrix and
+    ## @qcode{false} otherwise.  A matrix is an array of any type where
+    ## @code{ndims (@var{X}) == 2} and for which @code{size (@var{X})} returns
+    ## @code{[@var{H}, @var{W}]} with non-negative @var{H} and @var{W}.
+    ##
+    ## @end deftypefn
     function TF = ismatrix (this)
       TF = ismatrix (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} ismember (@var{A}, @var{B})
+    ##
+    ## Test for duration elements in a set.
+    ##
+    ## @code{@var{TF} = ismember (@var{A}, @var{B})} returns a logical array
+    ## @var{TF} of the same size as @var{A} containing @qcode{true} for each
+    ## corresponding element of @var{A} that is in @var{B} and @qcode{false}
+    ## otherwise.  @qcode{NaN} elements are not equal with each other and always
+    ## return @qcode{false}.
+    ##
+    ## @code{@var{TF} = ismember (@var{A}, @var{B}, @qcode{'rows'})} only
+    ## applies to duration matrices with the same number of columns, in which
+    ## case the logical vector @var{TF} contains @qcode{true} for each row of
+    ## @var{A} that is also a row in @var{B}.  @var{TF} has the same number of
+    ## rows as @var{A}.
+    ##
+    ## @code{[@var{TF}, @var{index}] = ismember (@var{A}, @var{B})} also returns
+    ## an index array of the same size as @var{A} containing the lowest index in
+    ## @var{B} for each element of @var{A} that is a member of @var{B} and 0
+    ## otherwise.  If the @qcode{'rows'} optional argument is used, then the
+    ## returning index is a column vector with the same rows as @var{A} and it
+    ## contains the lowest index in @var{B} for each row of @var{A} that is a
+    ## member of @var{B} and 0 otherwise.
+    ##
+    ## @end deftypefn
     function [TF, index] = ismember (A, B, varargin)
       ## Check input arguments
       do_rows = false;
@@ -761,35 +891,69 @@ classdef duration
       endif
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {duration} {@var{TF} =} ismissing (@var{D})
+    ## @deftypefnx {duration} {@var{TF} =} ismissing (@var{D}, @var{indicator})
+    ##
+    ## Test for missing elements in duration array.
+    ##
+    ## @var{TF} is a logical array of the same size as @var{D}.
+    ##
+    ## @end deftypefn
     function TF = ismissing (this, varargin)
-      if (nargin > 1)
+      if (nargin > 2)
         error ("duration.ismissing: too many input arguments.");
       endif
       if (! isempty (varargin))
-        if (! isa (varargin{1}, 'categorical'))
-          error (strcat ("duration.ismissing: INDICATOR", ...
-                         " argument must be of 'duration' type."));
-        endif
         indicator = varargin{1};
         TF = false (size (this));
-        for i = 1:numel (indicator)
-          days = days (indicator(i));
-          TF(this.Days == days) = true;
-        endfor
+        if (isvector (indicator))
+          if (! isa (varargin{1}, 'duration'))
+            for i = 1:numel (indicator)
+              TF(this.Days == days (indicator(i))) = true;
+            endfor
+          else
+            error ("duration.ismissing: INDICATOR must be a 'duration' array.");
+          endif
+        else
+          error ("duration.ismissing: INDICATOR must be a vector.");
+        endif
       else
-        TF = this.IsNaN;
+        TF = isnan (this.Days);
       endif
-      TF = isnan (this.Days);
     endfunction
 
     function TF = isnan (this)
       TF = isnan (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} isrow (@var{D})
+    ##
+    ## Return true if duration array is a row vector.
+    ##
+    ## @code{@var{TF} = isrow (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is a row vector
+    ## and @qcode{false} otherwise.  A row vector is a 2-D array for which
+    ## @code{size (@var{X})} returns @code{[1, @var{N}]} with non-negative
+    ## @var{N}.
+    ##
+    ## @end deftypefn
     function TF = isrow (this)
       TF = isrow (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} isscalar (@var{D})
+    ##
+    ## Return true if duration array is a scalar.
+    ##
+    ## @code{@var{TF} = isscalar (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is also a scalar
+    ## and @qcode{false} otherwise.  A scalar is a single element object for
+    ## which @code{size (@var{X})} returns @code{[1, 1]}.
+    ##
+    ## @end deftypefn
     function TF = isscalar (this)
       TF = isscalar (this.Days);
     endfunction
@@ -812,6 +976,18 @@ classdef duration
       TF = isequal (this.Days, sorted.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{TF} =} isvector (@var{D})
+    ##
+    ## Return true if duration array is a vector.
+    ##
+    ## @code{@var{TF} = isvector (@var{D})} returns a logical scalar @var{TF},
+    ## which is @qcode{true} if the duration array @var{D} is a vector and
+    ## @qcode{false} otherwise.  A vector is a 2-D array for which one of the
+    ## dimensions is equal to 1 (either @math{1xN} or @math{Nx1}).  By
+    ## definition, a scalar is also a vector.
+    ##
+    ## @end deftypefn
     function TF = isvector (this)
       TF = isvector (this.Days);
     endfunction
@@ -870,9 +1046,9 @@ classdef duration
 ## 'abs'              'plus'             'uplus'            'minus'           ##
 ## 'uminus'           'times'            'mtimes'           'ldivide'         ##
 ## 'mldivide'         'rdivide'          'mrdivide'         'colon'           ##
-## 'linspace'         'interp1'          'sum'              'cumsum'          ##
-## 'diff'             'mean'             'median'           'mode'            ##
-## 'floor'            'ceil'             'round'            'sign'            ##
+## 'linspace'         'sum'              'cumsum'           'diff'            ##
+## 'mean'             'median'           'mode'             'floor'           ##
+## 'ceil'             'round'            'sign'                               ##
 ##                                                                            ##
 ################################################################################
 
@@ -1052,16 +1228,6 @@ classdef duration
       C = fix_zero_precision (C);
     endfunction
 
-    function YI = interp1 (X, Y, XI, varargin)
-      if (isa (Y, 'duration'))
-        YI = Y;
-        YI.Days = interp1 (X.Days, Y.Days, XI.Days, varargin{:});
-        YI = fix_zero_precision (YI);
-      else
-        YI = interp1 (X.Days, Y, XI.Days, varargin{:});
-      endif
-    endfunction
-
     function S = sum (A, varargin)
       dim = [];
       if (! isempty (varargin))
@@ -1218,8 +1384,8 @@ classdef duration
 ################################################################################
 ##                             Available Methods                              ##
 ##                                                                            ##
-## 'sort'             'sortrows'         'unique'           'intersect'       ##
-## 'setdiff'          'setxor'           'union'                              ##
+## 'sort'             'sortrows'         'unique'           'interp1'         ##
+## 'intersect'        'setdiff'          'setxor'           'union'           ##
 ##                                                                            ##
 ################################################################################
 
@@ -1315,6 +1481,30 @@ classdef duration
       endif
     endfunction
 
+    function BI = interp1 (A, B, AI, varargin)
+      A_isDur = isa (A, 'duration');
+      B_isDur = isa (B, 'duration');
+      AIisDur = isa (AI, 'duration');
+      if (xor (A_isDur, AIisDur))
+        error ("duration.interp1: if A is a duration array, AI must be also.");
+      endif
+      if (B_isDur)
+        if (A_isDur)
+          BI = days (interp1 (A.Days, B.Days, AI.Days, varargin{:}));
+        elseif (isnumeric (A) && isnumeric (AI))
+          BI = days (interp1 (A, B.Days, AI, varargin{:}));
+        else
+          error (strcat ("duration.interp1: if A is not a duration", ...
+                         " array, then both A and AI must be numeric."));
+        endif
+        BI = fix_zero_precision (BI);
+      elseif (isnumeric (B))
+        BI = interp1 (A.Days, B, AI.Days, varargin{:});
+      else
+        error ("duration.interp1: B must be a duration or numeric array.");
+      endif
+    endfunction
+
     function [C, ixA, ixB] = intersect (A, B, varargin)
       [~, ixA, ixB] = intersect (A.Days, B.Days, varargin{:});
       C = subset (A, ixA);
@@ -1343,13 +1533,27 @@ classdef duration
 ##                             Available Methods                              ##
 ##                                                                            ##
 ## 'cat'              'horzcat'          'vertcat'          'repmat'          ##
-## 'reshape'          'circshift'        'permute'          'ipermute'        ##
-## 'transpose'        'ctranspose'                                            ##
+## 'repelem'          'repelems'         'reshape'          'circshift'       ##
+## 'permute'          'ipermute'         'transpose'        'ctranspose'      ##
 ##                                                                            ##
 ################################################################################
 
-  methods (Hidden)
+  methods (Access = public)
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{C} =} cat (@var{dim}, @var{A}, @var{B}, @dots{})
+    ##
+    ## Concatenate duration arrays.
+    ##
+    ## @code{@var{C} = cat (@var{dim}, @var{A}, @var{B}, @dots{})} concatenates
+    ## duration arrays @var{A}, @var{B}, @dots{} along dimension @var{dim}.  All
+    ## input arrays must have the same size except along the operating dimension
+    ## @var{dim}.  Any of the input arrays may also be string arrays or cell
+    ## arrays of character vectors of compatible size.  Additionally, an input
+    ## can be a numeric matrix, which when parsed to the constructor will return
+    ## a duration array of compatible size.
+    ##
+    ## @end deftypefn
     function out = cat (dim, varargin)
       args = varargin;
       [args{:}] = promote (varargin{:});
@@ -1358,38 +1562,227 @@ classdef duration
       out.Days = cat (dim, days{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{C} =} horzcat (@var{A}, @var{B}, @dots{})
+    ##
+    ## Horizontal concatenation of duration arrays.
+    ##
+    ## @code{@var{C} = horzcat (@var{A}, @var{B}, @dots{}} is the equivalent of
+    ## the syntax @code{@var{B} = [@var{A}, @var{B}, @dots{}]} and horizontally
+    ## concatenates the duration arrays @var{A}, @var{B}, @dots{}.  All input
+    ## arrays must have the same size except along the second dimension.  Any of
+    ## the input arrays may also be string arrays or cell arrays of character
+    ## vectors of compatible size.  Additionally, an input can be a numeric
+    ## matrix, which when parsed to the constructor will return a duration array
+    ## of compatible size.
+    ##
+    ## @end deftypefn
     function out = horzcat (varargin)
       out = cat (2, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{C} =} vertat (@var{A}, @var{B}, @dots{})
+    ##
+    ## Vertical concatenation of duration arrays.
+    ##
+    ## @code{@var{C} = vertat (@var{A}, @var{B}, @dots{}} is the equivalent of
+    ## the syntax @code{@var{B} = [@var{A}; @var{B}; @dots{}]} and vertically
+    ## concatenates the duration arrays @var{A}, @var{B}, @dots{}.  All input
+    ## arrays must have the same size except along the first dimension.  All of
+    ## the input arrays may also be string arrays or cell arrays of character
+    ## vectors of compatible size.  Additionally, an input can be a numeric
+    ## matrix, which when parsed to the constructor will return a duration array
+    ## of compatible size.
+    ##
+    ## @end deftypefn
     function out = vertcat (varargin)
       out = cat (1, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {duration} {@var{B} =} repmat (@var{A}, @var{n})
+    ## @deftypefnx {duration} {@var{B} =} repmat (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ## @deftypefnx {duration} {@var{B} =} repmat (@var{A}, @var{dimvec})
+    ##
+    ## Repeat copies of a duration array.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{n})} returns a duration array
+    ## @var{B} containing @var{n} copies of the input duration array @var{A}
+    ## along every dimension of @var{A}.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{d1}, @dots{}, @var{dN})} returns an
+    ## array @var{B} containing copies of @var{A} along the dimensions specified
+    ## by the list of scalar integer values @var{d1}, @dots{}, @var{dN}, which
+    ## specify how many copies of @var{A} are made in each dimension.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{dimvec})} is equivalent to the
+    ## previous syntax with @code{@var{dimvec} = [@var{d1}, @dots{}, @var{dN}]}.
+    ##
+    ## @end deftypefn
     function this = repmat (this, varargin)
       this.Days = repmat (this.Days, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {duration} {@var{B} =} repelem (@var{A}, @var{n})
+    ## @deftypefnx {duration} {@var{B} =} repelem (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ##
+    ## Repeat copies of duration array elements.
+    ##
+    ## @code{@var{B} = repelem (@var{A}, @var{n})} returns a duration vector
+    ## @var{B} containing repeated elements of the input @var{A}, which must be
+    ## a duration vector.  If @var{n} is a scalar, each element of @var{A} is
+    ## repeated @var{n} times along the non-singleton dimension of @var{A}.  If
+    ## @var{n} is a vector, it must have the same elemnts as @var{A}, in which
+    ## case it specifies the number of times to repeat each corresponding
+    ## element of @var{A}.
+    ##
+    ## @code{@var{B} =} repelem (@var{A}, @var{d1}, @dots{}, @var{dN}} returns
+    ## an array @var{B} with each element of @var{A} repeated according to the
+    ## the list of input arguments @code{@var{d1}, @dots{}, @var{dN}} each
+    ## corresponding to a different dimension @code{1:ndims (@var{A})} of the
+    ## input array @var{A}.  @var{d1}, @dots{}, @var{dN} must be either scalars
+    ## or vectors with the same length as the corresponding dimension of
+    ## @var{A} containing non-negative integer values specifying the number of
+    ## repetitions of each element along the corresponding dimension.
+    ##
+    ## @end deftypefn
+    function this = repelem (this, varargin)
+      this.Days = repelem (this.Days, varargin{:});
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{B} =} repelems (@var{A}, @var{R})
+    ##
+    ## Construct a vector of repeated duration array.
+    ##
+    ## @code{@var{B} = repelems (@var{A}, @var{R})} returns a duration vector
+    ## @var{B} containing repeated elements of the input @var{A}, which must be
+    ## a duration vector.  @var{R} must be a @math{2xN} matrix of integers.
+    ## Entries in the first row of @var{R} correspond to the linear indexing of
+    ## the elements in @var{A} to be repeated.  The corresponding entries in the
+    ## second row of @var{R} specify the repeat count of each element.
+    ##
+    ## @end deftypefn
+    function this = repelems (this, R)
+      this.Days = repelems (this.Days, R);
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn  {duration} {@var{B} =} reshape (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ## @deftypefnx {duration} {@var{B} =} reshape (@var{A}, @dots{}, @qcode{[]}, @dots{})
+    ## @deftypefnx {duration} {@var{B} =} reshape (@var{A}, @var{dimvec})
+    ##
+    ## Repeat copies of duration array elements.
+    ##
+    ## @code{@var{B} = reshape (@var{A}, @var{d1}, @dots{}, @var{dN})} returns a
+    ## duration array @var{B} with specified dimensions @var{d1}, @dots{},
+    ## @var{dN}, whose elements are taken columnwise from the duration array
+    ## @var{A}.  The product of @var{d1}, @dots{}, @var{dN} must equal the total
+    ## number of elements in @var{A}.
+    ##
+    ## @code{@var{B} = reshape (@var{A}, @dots{}, @qcode{[]}, @dots{})} returns
+    ## a duration array @var{B} with one dimension unspecified which is
+    ## calculated automatically so that the product of dimensions in @var{B}
+    ## matches the total elements in @var{A}, which must be divisible the
+    ## product of specified dimensions.  An empty matrix @qcode{([])} is used to
+    ## flag the unspecified dimension.
+    ##
+    ## @end deftypefn
     function this = reshape (this, varargin)
       this.Days = reshape (this.Days, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {duration} {@var{B} =} circshift (@var{A}, @var{n})
+    ## @deftypefnx {duration} {@var{B} =} circshift (@var{A}, @var{n}, @var{dim})
+    ##
+    ## Circularly shift the elements in a duration array.
+    ##
+    ## @code{@var{B} = circshift (@var{A}, @var{n})} circularly shifts the
+    ## elements of the duration array @var{A} according to @var{n}.  If @var{n}
+    ## is a nonzero integer scalar, then the elements of @var{A} are shifted by
+    ## @var{n} elements along the first non-singleton dimension of @var{A}.  If
+    ## @var{n} is a vector, it must not be longer that the number of dimensions
+    ## of @var{A} with each value of @var{n} corresponding to a dimension in
+    ## @var{A}.   The sign of the value(s) in @var{n} specify the direction in
+    ## the elements of @var{A} are shifted.
+    ##
+    ## @code{@var{B} = circshift (@var{A}, @var{n}, @var{dim})} circularly
+    ## shifts the elements of the duration array @var{A} along the dimension
+    ## specified by @var{dim}.  In this case, @var{n} must be a scalar integer
+    ## value.
+    ##
+    ## @end deftypefn
     function this = circshift (this, varargin)
       this.Days = circshift (this.Days, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{B} =} permute (@var{A}, @var{dims})
+    ##
+    ## Generalized transpose for a duration N-D array.
+    ##
+    ## @code{@var{B} = permute (@var{A}, @var{dims})} returns the generalized
+    ## transpose of the duration array @var{A} by rearranging its dimensions
+    ## according to the permutation vector specified in @var{dims}.
+    ##
+    ## @var{dims} must index all the dimensions @code{1:ndims (@var{A})} of the
+    ## input array @var{A}, in any order, but only once.  The @var{N}th
+    ## dimension of @var{A} gets remapped to the dimension in @var{B} specified
+    ## by @code{@var{dims}(@var{N})}.
+    ##
+    ## @end deftypefn
     function this = permute (this, order)
       this.Days = permute (this.Days, order);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{A} =} ipermute (@var{B}, @var{dims})
+    ##
+    ## Inverse of the generalized transpose for a duration N-D array.
+    ##
+    ## @code{@var{A} = ipermute (@var{B}, @var{dims})} returns the inverse of
+    ## the generalized transpose performed by the @code{permute} function.  The
+    ## expression @code{ipermute (permute (@var{A}, @var{dims}), @var{dims})}
+    ## returns the original array @var{A}.
+    ##
+    ## @var{dims} must index all the dimensions @code{1:ndims (@var{B})} of the
+    ## input array @var{B}, in any order, but only once.  The dimension of
+    ## @var{B} specified in @code{@var{dims}(@var{N})} gets remapped to the
+    ## @var{N}th dimension of @var{A}.
+    ##
+    ## @end deftypefn
     function this = ipermute (this, order)
       this.Days = ipermute (this.Days, order);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{B} =} transpose (@var{A})
+    ##
+    ## Transpose a duration matrix.
+    ##
+    ## @code{@var{B} = transpose (@var{A})} is the equivalent of the syntax
+    ## @code{@var{B} = @var{A}.'} and returns the transpose of the duration
+    ## matrix @var{A}.
+    ##
+    ## @end deftypefn
     function this = transpose (this)
       this.Days = transpose (this.Days);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {duration} {@var{B} =} ctranspose (@var{A})
+    ##
+    ## Transpose a duration matrix.
+    ##
+    ## @code{@var{B} = ctranspose (@var{A})} is the equivalent of the syntax
+    ## @code{@var{B} = @var{A}'} and returns the transpose of the duration
+    ## matrix @var{A}.  For duration arrays, @code{ctranspose} is identical to
+    ## @code{transpose}.
+    ##
+    ## @end deftypefn
     function this = ctranspose (this)
       this.Days = ctranspose (this.Days);
     endfunction
@@ -1401,13 +1794,13 @@ classdef duration
 ################################################################################
 ##                             Available Methods                              ##
 ##                                                                            ##
-## 'end'              'subsref'          'subsasgn'                           ##
+## 'end'              'subsref'          'subsasgn'         'subset'          ##
 ##                                                                            ##
 ################################################################################
 
   methods (Hidden)
 
-    ## Overloaded end keyword
+    ## Overload 'end' keyword
     function last_index = end (this, end_dim, ndim_obj)
       lastdim = ndims (this);
       if (end_dim == ndim_obj && ndim_obj == 1)
@@ -1458,8 +1851,17 @@ classdef duration
       endif
       switch (s.type)
         case '()'
-          if (! isa (val, "duration"))
-            val = duration (val);
+          if (isempty (val))
+            this.Days(s.subs{:}) = [];
+            return;
+          elseif (iscellstr (val) || ischar (val) || isa (val, {'string'}))
+            val = promote (val);
+          elseif (isnumeric (val))
+            val = duration (24 * double (val), 0, 0);
+          elseif (! isa (val, "duration"))
+            error (strcat ("duration.subsasgn: assignment value must", ...
+                           " be a duration array, a numeric array or", ...
+                           " text representing categories."));
           endif
           this.Days(s.subs{:}) = val.Days;
 
@@ -1490,35 +1892,16 @@ classdef duration
 
   methods (Access = private)
 
-    ## Promote numeric and string arrays to duration objects
-    function varargout = promote (varargin)
-      for i = 1:numel (varargin)
-        x = varargin{i};
-        if (isa (x, "duration"))
-          varargout{i} = x;
-        elseif (isnumeric (x))
-          ncols = size (x, 2);
-          if (isscalar (x))
-            varargout{i} = duration (24 * x, 0, 0);
-          elseif (ismatrix (x) && ncols == 3)
-            varargout{i} = duration (x);
-          else
-            error ("duration: invalid size input to constructor.");
-          endif
-        elseif (iscellstr (x) || ischar (x) || isa (x, "string"))
-          varargout{i} = duration (x);
-        else
-          error ("duration: invalid input to constructor.");
-        endif
-      endfor
-    endfunction
-
     ## Return a subset of a duration array
     function out = subset (this, varargin)
       out = this;
       out.Days = this.Days(varargin{:});
     endfunction
 
+  endmethods
+
+  methods (Access = private)
+
     ## Fix floating point precision near zero
     function this = fix_zero_precision (this)
       this.Days(this.Days > -1e-15 & this.Days < 1e-15) = 0;
@@ -1528,6 +1911,29 @@ classdef duration
 
 endclassdef
 
+## Promote numeric and string arrays to duration objects
+function varargout = promote (varargin)
+  for i = 1:numel (varargin)
+    x = varargin{i};
+    if (isa (x, "duration"))
+      varargout{i} = x;
+    elseif (isnumeric (x))
+      ncols = size (x, 2);
+      if (isscalar (x))
+        varargout{i} = duration (24 * x, 0, 0);
+      elseif (ismatrix (x) && ncols == 3)
+        varargout{i} = duration (x);
+      else
+        error ("duration: invalid size input to constructor.");
+      endif
+    elseif (iscellstr (x) || ischar (x) || isa (x, "string"))
+      varargout{i} = duration (x);
+    else
+      error ("duration: invalid input to constructor.");
+    endif
+  endfor
+endfunction
+
 ## Parse H, M, S, and MS numeric inputs into days
 function [err, days] = hms2days (H, MI, S, MS = 0)
   err = 0;
